@@ -160,19 +160,32 @@ def cli(input_path, output_path, table, archive, count, no_bar, warn, overwrite,
 
 
 	outcheck = alac.checkPath(output)
+
+	if "archive" in outcheck and archive==False:
+		if click.confirm("Make archive?"):
+			archive = True
+			supportArchive = True
+		else:
+			raise Exception("Alacorder quit.")
+
 	if overwrite == False and (outcheck == "overwrite_archive" or outcheck == "overwrite_table" or outcheck == "overwrite_all_tables"):
 		if click.confirm("Warning: Existing file at output path will be written over! Continue in OVERWRITE MODE?"):
 			overwrite = True
 			archive = True
+		else:
+			raise Exception("Alacorder quit.")
 	if overwrite == False and outcheck == "existing_archive":
 		if click.confirm("Appending to existing file at output path. Continue?"):
 			archive = True
+		else:
+			raise Exception("Alacorder quit.")
 
 	if outcheck == "archive" or outcheck == "existing_archive":
 		supportTable = False
 
 	if os.path.splitext(output)[1] == ".xls" or os.path.splitext(output)[1] == ".xlsx":
 		a = alac.config(path, table_path=output, table=table, GUI_mode=False, print_log=bar, warn=warn, max_cases=count, overwrite=overwrite, launch=launch, dedupe=dedupe, pager=pager, no_write=no_write)
+		click.echo(a.echo)
 		b = alac.parseCases(a)
  
 	if supportArchive == False and (outcheck == "archive" or outcheck == "existing_archive"):
@@ -194,6 +207,7 @@ def cli(input_path, output_path, table, archive, count, no_bar, warn, overwrite,
 
 	if archive:
 		a = alac.config(path, archive_path=output, GUI_mode=False, print_log=bar, warn=warn, max_cases=count, overwrite=overwrite, launch=launch, mk_archive=True, dedupe=dedupe, pager=pager, no_write=no_write)
+		click.echo(a.echo)
 		b = a.map(lambda x: getBool(x))
 		c = a[b == True]
 		b = alac.writeArchive(a)
@@ -216,12 +230,14 @@ def cli(input_path, output_path, table, archive, count, no_bar, warn, overwrite,
 				click.echo("WARNING: Invalid table selection - defaulting to \'cases\'...")
 			table = "cases"
 		a = alac.config(path, table_path=output, table=table, GUI_mode=False, print_log=bar, warn=warn, max_cases=count, overwrite=overwrite, launch=launch, dedupe=dedupe, pager=pager, no_write=no_write)
+		click.echo(a.echo)
 		b = a.map(lambda x: getBool(x))
 		c = a[b == True]
 		b = alac.parseTable(a)
 
 	elif supportTable and (outcheck == "all" or outcheck == "all_tables" or outcheck == "overwrite_all_tables"):
 		a = alac.config(path, table_path=output, table=table, GUI_mode=False, print_log=bar, warn=warn,max_cases=count, overwrite=overwrite, launch=launch, dedupe=dedupe, pager=pager, no_write=no_write)
+		click.echo(a.echo)
 		b = alac.parseTable(a)
 
 
